@@ -135,7 +135,7 @@ class Recipe(object):
         content = ['#!/bin/sh']
         for key, val in self._get_env().items():
             content.append('export %s=%s' % (key, val))
-        content.append('%s $*' % path)
+        content.append('%s "$@"' % path)
         name = os.path.basename(path)
         bindir = self.buildout['buildout']['bin-directory']
         executable = os.path.join(bindir, name)
